@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020-2021 Univention GmbH
+# Copyright 2020-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -39,6 +39,13 @@ class TestUCR(object):
 	def get(self, key, default=None):
 		return self.items.get(key, default)
 
+	def get_int(self, key, default=None):
+		val = self.get(key)
+		try:
+			return int(val)
+		except (TypeError, ValueError):
+			return default
+
 	def __contains__(self, key):
 		return key in self.items
 
@@ -55,14 +62,14 @@ class TestUCR(object):
 	def keys(self):
 		return self.items.keys()
 
-	def is_false(self, key=None, default=False, value=None):  # noqa F811
+	def is_false(self, key=None, default=False, value=None):  # noqa: F811
 		if value is None:
 			value = self.get(key)  # type: ignore
 			if value is None:
 				return default
 		return value.lower() in ('no', 'false', '0', 'disable', 'disabled', 'off')
 
-	def is_true(self, key=None, default=False, value=None):  # noqa F811
+	def is_true(self, key=None, default=False, value=None):  # noqa: F811
 		if value is None:
 			value = self.get(key)  # type: ignore
 			if value is None:
@@ -74,5 +81,5 @@ class TestUCR(object):
 
 
 @pytest.fixture
-def ucr():
+def mock_ucr():
 	return TestUCR()
